@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkMacPort.h 1.33 96/07/31 14:44:13
+ * SCCS: @(#) tkMacPort.h 1.52 97/07/28 11:18:59
  */
 
 #ifndef _TKMACPORT
@@ -38,10 +38,7 @@
 #include <time.h>
 #include <stdlib.h>
 #include <string.h>
-#include <math.h>
-#if (defined(THINK_C) || defined(__MWERKS__))
-double hypot(double x, double y);
-#endif
+#include "tclMath.h"
 #include <ctype.h>
 #include <limits.h>
 
@@ -67,35 +64,22 @@ extern int errno;
 #   define NBBY 8
 #endif
 
-/*
- * Widget commands for the Native Macintosh look & feel.
- */
-EXTERN int	Tk_MacScrollbarCmd(ClientData clientData, Tcl_Interp *interp,
-			int argc, char **argv);
-
-/*
- * Hack to correct bugs in Macintosh version of fopen.  This
- * is needed in the parts of Tk that have not yet been converted
- * to use channels.  It works around various problems with fopen
- * such as not understanding file paths which include aliases.
- */
-EXTERN FILE * TclMacFOpenHack _ANSI_ARGS_((const char *path,
-	const char *mode));
-#define fopen(path, mode) TclMacFOpenHack(path, mode)
-
 /*
  * Declarations for various library procedures that may not be declared
  * in any other header file.
  */
 
-extern void panic();
-extern int strncasecmp _ANSI_ARGS_((const char *s1, const char *s2,
-	size_t length));
+extern void 		panic  _ANSI_ARGS_(TCL_VARARGS(char *, string));
+extern int		strcasecmp _ANSI_ARGS_((CONST char *s1,
+			    CONST char *s2));
+extern int		strncasecmp _ANSI_ARGS_((CONST char *s1,
+			    CONST char *s2, size_t n));
 
 /*
  * Defines for X functions that are used by Tk but are treated as
  * no-op functions on the Macintosh.
  */
+
 #define XFlush(display)
 #define XFree(data) {if ((data) != NULL) ckfree((char *) (data));}
 #define XGrabServer(display)
@@ -108,9 +92,54 @@ extern int strncasecmp _ANSI_ARGS_((const char *s1, const char *s2,
 /*
  * The following functions are not used on the Mac, so we stub it out.
  */
-#define TkSetPixmapColormap(p,c) {}
+
 #define TkFreeWindowId(dispPtr,w)
 #define TkInitXId(dispPtr)
-#define Tk_FreeXId(display, xid)
+#define TkpCmapStressed(tkwin,colormap) (0)
+#define TkpFreeColor(tkColPtr)
+#define TkSetPixmapColormap(p,c) {}
+#define Tk_FreeXId(display,xid)
+#define TkpSync(display)
+
+/*
+ * The following macro returns the pixel value that corresponds to the
+ * RGB values in the given XColor structure.
+ */
+
+#define PIXEL_MAGIC ((unsigned char) 0x69)
+#define TkpGetPixel(p) ((((((PIXEL_MAGIC << 8) \
+	| (((p)->red >> 8) & 0xff)) << 8) \
+	| (((p)->green >> 8) & 0xff)) << 8) \
+	| (((p)->blue >> 8) & 0xff))
+
+/*
+ * This macro stores a representation of the window handle in a string.
+ */
+
+#define TkpPrintWindowId(buf,w) \
+	sprintf((buf), "0x%x", (unsigned int) (w))
+	    
+/*
+ * TkpScanWindowId is just an alias for Tcl_GetInt on Unix.
+ */
+
+#define TkpScanWindowId(i,s,wp) \
+	Tcl_GetInt((i),(s),(wp))
+
+/*
+ * Magic pixel values for dynamic (or active) colors.
+ */
+
+#define HIGHLIGHT_PIXEL			31
+#define HIGHLIGHT_TEXT_PIXEL		33
+#define CONTROL_TEXT_PIXEL		35
+#define CONTROL_BODY_PIXEL		37
+#define CONTROL_FRAME_PIXEL		39
+#define WINDOW_BODY_PIXEL		41
+#define MENU_ACTIVE_PIXEL		43
+#define MENU_ACTIVE_TEXT_PIXEL		45
+#define MENU_BACKGROUND_PIXEL		47
+#define MENU_DISABLED_PIXEL		49
+#define MENU_TEXT_PIXEL			51
 
 #endif /* _TKMACPORT */
